@@ -29,18 +29,24 @@ class TransactionRepository(Repository):
     def get_transactions_before_date(self, user_id, date):
         return self.transaction_store.fetch_transactions_before_date(user_id, date)
 
-    def add_transaction(self, user_id, volume, symbol, value, price, currency, date, source, source_id):
+    def add_transaction(self, user_id, volume, symbol, value, price, currency, date, source, source_id, transaction_type,
+                        order_type):
         t = user_transaction(user_id=user_id, volume=volume, symbol=symbol, value=value, price=price,
                              currency=currency, date=date, source=source, source_id=source_id,
-                             operation=OPERATIONS.ADDED.name, is_valid=True, invalid_reason="")
+                             operation=OPERATIONS.ADDED.name, is_valid=True, invalid_reason="",
+                             type=transaction_type, order_type = order_type
+                             )
         self.memories[TRANSACTIONS_MEMORY_KEY].items.append(t)
         return t
 
-    def edit_transaction(self, in_id, user_id, volume, symbol, value, price, currency, date, source, source_id):
+    def edit_transaction(self, in_id, user_id, volume, symbol, value, price, currency, date, source, source_id, transaction_type,
+                         order_type):
         t = user_transaction(id=in_id,
                              user_id=user_id, volume=volume, symbol=symbol, value=value, price=price,
                              currency=currency, date=date, source=source, source_id=source_id,
-                             operation=OPERATIONS.MODIFIED.name)
+                             operation=OPERATIONS.MODIFIED.name,
+                             type=transaction_type, order_type=order_type
+                             )
         self.memories[TRANSACTIONS_MEMORY_KEY].items.append(t)
         return t
 
